Module: Google::Apis::ObservabilityV1
- Defined in:
- lib/google/apis/observability_v1.rb,
lib/google/apis/observability_v1/classes.rb,
lib/google/apis/observability_v1/service.rb,
lib/google/apis/observability_v1/gem_version.rb,
lib/google/apis/observability_v1/representations.rb
Overview
Observability API
Provides functionality for configuring the observability scope, which controls the log, metric, and trace data that you can view.
Defined Under Namespace
Classes: Bucket, CancelOperationRequest, CloudObservabilityService, CmekSettings, Dataset, Empty, Link, ListBucketsResponse, ListDatasetsResponse, ListLinksResponse, ListLocationsResponse, ListOperationsResponse, ListTraceScopesResponse, ListViewsResponse, Location, Operation, OperationMetadata, Scope, Settings, Status, TraceScope, View
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-observability_v1 gem
"0.16.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260409"- VERSION =
Version of the Observability API this client connects to. This is NOT the gem version.
'V1'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'