Class: Google::Apis::ObservabilityV1::CmekSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/observability_v1/classes.rb,
lib/google/apis/observability_v1/representations.rb,
lib/google/apis/observability_v1/representations.rb

Overview

Settings for configuring CMEK for a bucket.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CmekSettings

Returns a new instance of CmekSettings.



128
129
130
# File 'lib/google/apis/observability_v1/classes.rb', line 128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_keyString

Optional. The resource name for the configured Cloud KMS key. The format is: projects/[PROJECT_ID]/locations/[LOCATION]/keyRings/[KEYRING]/cryptoKeys/[KEY] For example: projects/my-project/locations/us-central1/keyRings/my-ring/ cryptoKeys/my-key Corresponds to the JSON property kmsKey

Returns:

  • (String)


110
111
112
# File 'lib/google/apis/observability_v1/classes.rb', line 110

def kms_key
  @kms_key
end

#kms_key_versionString

Output only. The CryptoKeyVersion resource name for the configured Cloud KMS key. The format is: projects/[PROJECT_ID]/locations/[LOCATION]/keyRings/[ KEYRING]/cryptoKeys/[KEY]/cryptoKeyVersions/[VERSION] For example: projects/my- project/locations/us-central1/keyRings/my-ring/cryptoKeys/my-key/ cryptoKeyVersions/1 This read-only field is used to convey the specific configured CryptoKeyVersion of the kms_key that has been configured. It is populated when the CMEK settings are bound to a single key version. Corresponds to the JSON property kmsKeyVersion

Returns:

  • (String)


121
122
123
# File 'lib/google/apis/observability_v1/classes.rb', line 121

def kms_key_version
  @kms_key_version
end

#service_account_idString

Output only. The service account used to access the key. Corresponds to the JSON property serviceAccountId

Returns:

  • (String)


126
127
128
# File 'lib/google/apis/observability_v1/classes.rb', line 126

def 
  @service_account_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



133
134
135
136
137
# File 'lib/google/apis/observability_v1/classes.rb', line 133

def update!(**args)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version)
  @service_account_id = args[:service_account_id] if args.key?(:service_account_id)
end