Class: Google::Apis::ObservabilityV1::ListTraceScopesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/observability_v1/classes.rb,
lib/google/apis/observability_v1/representations.rb,
lib/google/apis/observability_v1/representations.rb

Overview

Response for listing TraceScopes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListTraceScopesResponse

Returns a new instance of ListTraceScopesResponse.



398
399
400
# File 'lib/google/apis/observability_v1/classes.rb', line 398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Optional. If there might be more results than appear in this response, then next_page_token is included. To get the next set of results, call the same method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


391
392
393
# File 'lib/google/apis/observability_v1/classes.rb', line 391

def next_page_token
  @next_page_token
end

#trace_scopesArray<Google::Apis::ObservabilityV1::TraceScope>

Optional. A list of trace scopes. Corresponds to the JSON property traceScopes



396
397
398
# File 'lib/google/apis/observability_v1/classes.rb', line 396

def trace_scopes
  @trace_scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



403
404
405
406
# File 'lib/google/apis/observability_v1/classes.rb', line 403

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @trace_scopes = args[:trace_scopes] if args.key?(:trace_scopes)
end