Class: Google::Apis::ObservabilityV1::Scope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/observability_v1/classes.rb,
lib/google/apis/observability_v1/representations.rb,
lib/google/apis/observability_v1/representations.rb

Overview

Message describing Scope object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Scope

Returns a new instance of Scope.



632
633
634
# File 'lib/google/apis/observability_v1/classes.rb', line 632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#log_scopeString

Required. The full resource name of the LogScope. For example: //logging. googleapis.com/projects/myproject/locations/global/logScopes/my-log-scope Corresponds to the JSON property logScope

Returns:

  • (String)


611
612
613
# File 'lib/google/apis/observability_v1/classes.rb', line 611

def log_scope
  @log_scope
end

#nameString

Identifier. Name of the resource. The format is: projects/project/locations/ location/scopes/scope The location field must be set to global. The scope field must be set to _Default. Corresponds to the JSON property name

Returns:

  • (String)


618
619
620
# File 'lib/google/apis/observability_v1/classes.rb', line 618

def name
  @name
end

#trace_scopeString

Required. The resource name of the TraceScope. For example: projects/ myproject/locations/global/traceScopes/my-trace-scope Corresponds to the JSON property traceScope

Returns:

  • (String)


624
625
626
# File 'lib/google/apis/observability_v1/classes.rb', line 624

def trace_scope
  @trace_scope
end

#update_timeString

Output only. Update timestamp. Note: The Update timestamp for the default scope is initially unset. Corresponds to the JSON property updateTime

Returns:

  • (String)


630
631
632
# File 'lib/google/apis/observability_v1/classes.rb', line 630

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



637
638
639
640
641
642
# File 'lib/google/apis/observability_v1/classes.rb', line 637

def update!(**args)
  @log_scope = args[:log_scope] if args.key?(:log_scope)
  @name = args[:name] if args.key?(:name)
  @trace_scope = args[:trace_scope] if args.key?(:trace_scope)
  @update_time = args[:update_time] if args.key?(:update_time)
end