Class: Google::Apis::ObservabilityV1::TraceScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/observability_v1/classes.rb,
lib/google/apis/observability_v1/representations.rb,
lib/google/apis/observability_v1/representations.rb

Overview

A trace scope is a collection of resources whose traces are queried together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TraceScope

Returns a new instance of TraceScope.



760
761
762
# File 'lib/google/apis/observability_v1/classes.rb', line 760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of the trace scope. Corresponds to the JSON property createTime

Returns:

  • (String)


735
736
737
# File 'lib/google/apis/observability_v1/classes.rb', line 735

def create_time
  @create_time
end

#descriptionString

Optional. Describes this trace scope. The maximum length of the description is 8000 characters. Corresponds to the JSON property description

Returns:

  • (String)


741
742
743
# File 'lib/google/apis/observability_v1/classes.rb', line 741

def description
  @description
end

#nameString

Identifier. The resource name of the trace scope. For example: projects/my- project/locations/global/traceScopes/my-trace-scope Corresponds to the JSON property name

Returns:

  • (String)


747
748
749
# File 'lib/google/apis/observability_v1/classes.rb', line 747

def name
  @name
end

#resource_namesArray<String>

Required. Names of the projects that are included in this trace scope. * projects/[PROJECT_ID] A trace scope can include a maximum of 20 projects. Corresponds to the JSON property resourceNames

Returns:

  • (Array<String>)


753
754
755
# File 'lib/google/apis/observability_v1/classes.rb', line 753

def resource_names
  @resource_names
end

#update_timeString

Output only. The last update timestamp of the trace scope. Corresponds to the JSON property updateTime

Returns:

  • (String)


758
759
760
# File 'lib/google/apis/observability_v1/classes.rb', line 758

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



765
766
767
768
769
770
771
# File 'lib/google/apis/observability_v1/classes.rb', line 765

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @resource_names = args[:resource_names] if args.key?(:resource_names)
  @update_time = args[:update_time] if args.key?(:update_time)
end