Class: Google::Apis::ObservabilityV1::CloudObservabilityService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ObservabilityV1::CloudObservabilityService
- Defined in:
- lib/google/apis/observability_v1/service.rb
Overview
Observability API
Provides functionality for configuring the observability scope, which controls the log, metric, and trace data that you can view.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://observability.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_folder_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#cancel_organization_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_bucket_dataset_link(parent, link_object = nil, link_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Create a new link.
-
#create_project_location_trace_scope(parent, trace_scope_object = nil, trace_scope_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::TraceScope
Create a new TraceScope.
-
#delete_folder_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Deletes a long-running operation.
-
#delete_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Deletes a long-running operation.
-
#delete_project_location_bucket_dataset_link(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Delete a link.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Deletes a long-running operation.
-
#delete_project_location_trace_scope(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Delete a TraceScope.
-
#get_folder_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Location
Gets information about a location.
-
#get_folder_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Gets the latest state of a long-running operation.
-
#get_folder_location_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Settings
Get Settings.
-
#get_organization_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Location
Gets information about a location.
-
#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Gets the latest state of a long-running operation.
-
#get_organization_location_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Settings
Get Settings.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Location
Gets information about a location.
-
#get_project_location_bucket(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Bucket
Get bucket resource.
-
#get_project_location_bucket_dataset(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Dataset
Get a dataset.
-
#get_project_location_bucket_dataset_link(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Link
Get a link.
-
#get_project_location_bucket_dataset_view(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::View
Get a view.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_scope(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Scope
Gets details of a single Scope.
-
#get_project_location_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Settings
Get Settings.
-
#get_project_location_trace_scope(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::TraceScope
Get TraceScope resource.
-
#initialize ⇒ CloudObservabilityService
constructor
A new instance of CloudObservabilityService.
-
#list_folder_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_folder_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#list_project_location_bucket_dataset_links(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListLinksResponse
List links of a dataset.
-
#list_project_location_bucket_dataset_views(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListViewsResponse
List views of a dataset.
-
#list_project_location_bucket_datasets(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListDatasetsResponse
List datasets of a bucket.
-
#list_project_location_buckets(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListBucketsResponse
List buckets of a project in a particular location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_trace_scopes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListTraceScopesResponse
List TraceScopes of a project in a particular location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_bucket_dataset_link(name, link_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Update a link.
-
#patch_project_location_scope(name, scope_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Scope
Updates the parameters of a single Scope.
-
#patch_project_location_trace_scope(name, trace_scope_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::TraceScope
Update a TraceScope.
-
#update_folder_location_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Update Settings.
-
#update_organization_location_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Update Settings.
-
#update_project_location_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Update Settings.
Constructor Details
#initialize ⇒ CloudObservabilityService
Returns a new instance of CloudObservabilityService.
48 49 50 51 52 53 |
# File 'lib/google/apis/observability_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-observability_v1', client_version: Google::Apis::ObservabilityV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/observability_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/observability_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#cancel_folder_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/google/apis/observability_v1/service.rb', line 238 def cancel_folder_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::ObservabilityV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::ObservabilityV1::Empty::Representation command.response_class = Google::Apis::ObservabilityV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/google/apis/observability_v1/service.rb', line 1251 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::ObservabilityV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::ObservabilityV1::Empty::Representation command.response_class = Google::Apis::ObservabilityV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_organization_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
546 547 548 549 550 551 552 553 554 555 556 |
# File 'lib/google/apis/observability_v1/service.rb', line 546 def cancel_organization_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::ObservabilityV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::ObservabilityV1::Empty::Representation command.response_class = Google::Apis::ObservabilityV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_bucket_dataset_link(parent, link_object = nil, link_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Create a new link.
999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 |
# File 'lib/google/apis/observability_v1/service.rb', line 999 def create_project_location_bucket_dataset_link(parent, link_object = nil, link_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/links', ) command.request_representation = Google::Apis::ObservabilityV1::Link::Representation command.request_object = link_object command.response_representation = Google::Apis::ObservabilityV1::Operation::Representation command.response_class = Google::Apis::ObservabilityV1::Operation command.params['parent'] = parent unless parent.nil? command.query['linkId'] = link_id unless link_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_trace_scope(parent, trace_scope_object = nil, trace_scope_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::TraceScope
Create a new TraceScope.
1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 |
# File 'lib/google/apis/observability_v1/service.rb', line 1475 def create_project_location_trace_scope(parent, trace_scope_object = nil, trace_scope_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/traceScopes', ) command.request_representation = Google::Apis::ObservabilityV1::TraceScope::Representation command.request_object = trace_scope_object command.response_representation = Google::Apis::ObservabilityV1::TraceScope::Representation command.response_class = Google::Apis::ObservabilityV1::TraceScope command.params['parent'] = parent unless parent.nil? command.query['traceScopeId'] = trace_scope_id unless trace_scope_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_folder_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
273 274 275 276 277 278 279 280 281 |
# File 'lib/google/apis/observability_v1/service.rb', line 273 def delete_folder_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Empty::Representation command.response_class = Google::Apis::ObservabilityV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
581 582 583 584 585 586 587 588 589 |
# File 'lib/google/apis/observability_v1/service.rb', line 581 def delete_organization_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Empty::Representation command.response_class = Google::Apis::ObservabilityV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_bucket_dataset_link(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Delete a link.
1033 1034 1035 1036 1037 1038 1039 1040 1041 |
# File 'lib/google/apis/observability_v1/service.rb', line 1033 def delete_project_location_bucket_dataset_link(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Operation::Representation command.response_class = Google::Apis::ObservabilityV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/google/apis/observability_v1/service.rb', line 1286 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Empty::Representation command.response_class = Google::Apis::ObservabilityV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_trace_scope(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Empty
Delete a TraceScope.
1510 1511 1512 1513 1514 1515 1516 1517 1518 |
# File 'lib/google/apis/observability_v1/service.rb', line 1510 def delete_project_location_trace_scope(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Empty::Representation command.response_class = Google::Apis::ObservabilityV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/observability_v1/service.rb', line 75 def get_folder_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Location::Representation command.response_class = Google::Apis::ObservabilityV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
304 305 306 307 308 309 310 311 312 |
# File 'lib/google/apis/observability_v1/service.rb', line 304 def get_folder_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Operation::Representation command.response_class = Google::Apis::ObservabilityV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Settings
Get Settings
107 108 109 110 111 112 113 114 115 |
# File 'lib/google/apis/observability_v1/service.rb', line 107 def get_folder_location_settings(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Settings::Representation command.response_class = Google::Apis::ObservabilityV1::Settings command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Location
Gets information about a location.
383 384 385 386 387 388 389 390 391 |
# File 'lib/google/apis/observability_v1/service.rb', line 383 def get_organization_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Location::Representation command.response_class = Google::Apis::ObservabilityV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
612 613 614 615 616 617 618 619 620 |
# File 'lib/google/apis/observability_v1/service.rb', line 612 def get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Operation::Representation command.response_class = Google::Apis::ObservabilityV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Settings
Get Settings
415 416 417 418 419 420 421 422 423 |
# File 'lib/google/apis/observability_v1/service.rb', line 415 def get_organization_location_settings(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Settings::Representation command.response_class = Google::Apis::ObservabilityV1::Settings command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Location
Gets information about a location.
691 692 693 694 695 696 697 698 699 |
# File 'lib/google/apis/observability_v1/service.rb', line 691 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Location::Representation command.response_class = Google::Apis::ObservabilityV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_bucket(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Bucket
Get bucket resource.
847 848 849 850 851 852 853 854 855 |
# File 'lib/google/apis/observability_v1/service.rb', line 847 def get_project_location_bucket(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Bucket::Representation command.response_class = Google::Apis::ObservabilityV1::Bucket command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_bucket_dataset(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Dataset
Get a dataset.
921 922 923 924 925 926 927 928 929 |
# File 'lib/google/apis/observability_v1/service.rb', line 921 def get_project_location_bucket_dataset(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Dataset::Representation command.response_class = Google::Apis::ObservabilityV1::Dataset command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_bucket_dataset_link(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Link
Get a link.
1064 1065 1066 1067 1068 1069 1070 1071 1072 |
# File 'lib/google/apis/observability_v1/service.rb', line 1064 def get_project_location_bucket_dataset_link(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Link::Representation command.response_class = Google::Apis::ObservabilityV1::Link command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_bucket_dataset_view(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::View
Get a view.
1173 1174 1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/google/apis/observability_v1/service.rb', line 1173 def get_project_location_bucket_dataset_view(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::View::Representation command.response_class = Google::Apis::ObservabilityV1::View command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1317 1318 1319 1320 1321 1322 1323 1324 1325 |
# File 'lib/google/apis/observability_v1/service.rb', line 1317 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Operation::Representation command.response_class = Google::Apis::ObservabilityV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_scope(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Scope
Gets details of a single Scope.
1398 1399 1400 1401 1402 1403 1404 1405 1406 |
# File 'lib/google/apis/observability_v1/service.rb', line 1398 def get_project_location_scope(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Scope::Representation command.response_class = Google::Apis::ObservabilityV1::Scope command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Settings
Get Settings
723 724 725 726 727 728 729 730 731 |
# File 'lib/google/apis/observability_v1/service.rb', line 723 def get_project_location_settings(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::Settings::Representation command.response_class = Google::Apis::ObservabilityV1::Settings command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_trace_scope(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::TraceScope
Get TraceScope resource.
1542 1543 1544 1545 1546 1547 1548 1549 1550 |
# File 'lib/google/apis/observability_v1/service.rb', line 1542 def get_project_location_trace_scope(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ObservabilityV1::TraceScope::Representation command.response_class = Google::Apis::ObservabilityV1::TraceScope command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_folder_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/google/apis/observability_v1/service.rb', line 349 def list_folder_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::ObservabilityV1::ListOperationsResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_folder_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/google/apis/observability_v1/service.rb', line 159 def list_folder_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::ObservabilityV1::ListLocationsResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
657 658 659 660 661 662 663 664 665 666 667 668 669 |
# File 'lib/google/apis/observability_v1/service.rb', line 657 def list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::ObservabilityV1::ListOperationsResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/google/apis/observability_v1/service.rb', line 467 def list_organization_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::ObservabilityV1::ListLocationsResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_bucket_dataset_links(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListLinksResponse
List links of a dataset.
1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 |
# File 'lib/google/apis/observability_v1/service.rb', line 1103 def list_project_location_bucket_dataset_links(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/links', ) command.response_representation = Google::Apis::ObservabilityV1::ListLinksResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListLinksResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_bucket_dataset_views(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListViewsResponse
List views of a dataset.
1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 |
# File 'lib/google/apis/observability_v1/service.rb', line 1211 def list_project_location_bucket_dataset_views(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/views', ) command.response_representation = Google::Apis::ObservabilityV1::ListViewsResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListViewsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_bucket_datasets(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListDatasetsResponse
List datasets of a bucket.
961 962 963 964 965 966 967 968 969 970 971 972 |
# File 'lib/google/apis/observability_v1/service.rb', line 961 def list_project_location_bucket_datasets(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/datasets', ) command.response_representation = Google::Apis::ObservabilityV1::ListDatasetsResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListDatasetsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_buckets(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListBucketsResponse
List buckets of a project in a particular location.
887 888 889 890 891 892 893 894 895 896 897 898 |
# File 'lib/google/apis/observability_v1/service.rb', line 887 def list_project_location_buckets(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/buckets', ) command.response_representation = Google::Apis::ObservabilityV1::ListBucketsResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListBucketsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 |
# File 'lib/google/apis/observability_v1/service.rb', line 1362 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::ObservabilityV1::ListOperationsResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_trace_scopes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListTraceScopesResponse
List TraceScopes of a project in a particular location.
1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 |
# File 'lib/google/apis/observability_v1/service.rb', line 1583 def list_project_location_trace_scopes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/traceScopes', ) command.response_representation = Google::Apis::ObservabilityV1::ListTraceScopesResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListTraceScopesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'lib/google/apis/observability_v1/service.rb', line 775 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::ObservabilityV1::ListLocationsResponse::Representation command.response_class = Google::Apis::ObservabilityV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_bucket_dataset_link(name, link_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Update a link.
1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 |
# File 'lib/google/apis/observability_v1/service.rb', line 1139 def patch_project_location_bucket_dataset_link(name, link_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ObservabilityV1::Link::Representation command.request_object = link_object command.response_representation = Google::Apis::ObservabilityV1::Operation::Representation command.response_class = Google::Apis::ObservabilityV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_scope(name, scope_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Scope
Updates the parameters of a single Scope.
1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 |
# File 'lib/google/apis/observability_v1/service.rb', line 1437 def patch_project_location_scope(name, scope_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ObservabilityV1::Scope::Representation command.request_object = scope_object command.response_representation = Google::Apis::ObservabilityV1::Scope::Representation command.response_class = Google::Apis::ObservabilityV1::Scope command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_trace_scope(name, trace_scope_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::TraceScope
Update a TraceScope.
1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'lib/google/apis/observability_v1/service.rb', line 1619 def patch_project_location_trace_scope(name, trace_scope_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ObservabilityV1::TraceScope::Representation command.request_object = trace_scope_object command.response_representation = Google::Apis::ObservabilityV1::TraceScope::Representation command.response_class = Google::Apis::ObservabilityV1::TraceScope command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_folder_location_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Update Settings
197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/google/apis/observability_v1/service.rb', line 197 def update_folder_location_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ObservabilityV1::Settings::Representation command.request_object = settings_object command.response_representation = Google::Apis::ObservabilityV1::Operation::Representation command.response_class = Google::Apis::ObservabilityV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_organization_location_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Update Settings
505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/google/apis/observability_v1/service.rb', line 505 def update_organization_location_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ObservabilityV1::Settings::Representation command.request_object = settings_object command.response_representation = Google::Apis::ObservabilityV1::Operation::Representation command.response_class = Google::Apis::ObservabilityV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_location_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ObservabilityV1::Operation
Update Settings
813 814 815 816 817 818 819 820 821 822 823 824 |
# File 'lib/google/apis/observability_v1/service.rb', line 813 def update_project_location_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ObservabilityV1::Settings::Representation command.request_object = settings_object command.response_representation = Google::Apis::ObservabilityV1::Operation::Representation command.response_class = Google::Apis::ObservabilityV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |