Class: Google::Apis::ObservabilityV1::Settings
- Inherits:
-
Object
- Object
- Google::Apis::ObservabilityV1::Settings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/observability_v1/classes.rb,
lib/google/apis/observability_v1/representations.rb,
lib/google/apis/observability_v1/representations.rb
Overview
Describes the settings associated with a project, organization, or folder.
Instance Attribute Summary collapse
-
#default_storage_location ⇒ String
Optional.
-
#kms_key_name ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#service_account_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Settings
constructor
A new instance of Settings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Settings
Returns a new instance of Settings.
676 677 678 |
# File 'lib/google/apis/observability_v1/classes.rb', line 676 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_storage_location ⇒ String
Optional. The location which should be used when any regional resources are
provisioned by Google Cloud.
Corresponds to the JSON property defaultStorageLocation
653 654 655 |
# File 'lib/google/apis/observability_v1/classes.rb', line 653 def default_storage_location @default_storage_location end |
#kms_key_name ⇒ String
Optional. The resource name for the configured Cloud KMS key. KMS key name
format: "projects/[PROJECT_ID]/locations/[LOCATION]/keyRings/[KEYRING]/
cryptoKeys/[KEY]" For example: "projects/my-project/locations/us-central1/
keyRings/my-ring/cryptoKeys/my-key"
Corresponds to the JSON property kmsKeyName
661 662 663 |
# File 'lib/google/apis/observability_v1/classes.rb', line 661 def kms_key_name @kms_key_name end |
#name ⇒ String
Identifier. The resource name of the settings.
Corresponds to the JSON property name
666 667 668 |
# File 'lib/google/apis/observability_v1/classes.rb', line 666 def name @name end |
#service_account_id ⇒ String
Output only. The service account for the given resource container, such as
project or folder. This will be used by Cloud Observability to perform actions
in the container's project like access KMS keys or create Links. Always the
same service account per resource container regardless of region.
Corresponds to the JSON property serviceAccountId
674 675 676 |
# File 'lib/google/apis/observability_v1/classes.rb', line 674 def service_account_id @service_account_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
681 682 683 684 685 686 |
# File 'lib/google/apis/observability_v1/classes.rb', line 681 def update!(**args) @default_storage_location = args[:default_storage_location] if args.key?(:default_storage_location) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @name = args[:name] if args.key?(:name) @service_account_id = args[:service_account_id] if args.key?(:service_account_id) end |